@@ -576,6 +576,8 @@ This package provides the following public methods:
 
 =cut
 
+use 5.006;	# For 'our', at least.
+
 package Games::Sudoku::General;
 
 use strict;
@@ -583,7 +585,7 @@ use warnings;
 
 use base qw{Exporter};
 
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 our @EXPORT_OK = qw{
 	SUDOKU_SUCCESS
 	SUDOKU_NO_SOLUTION
@@ -2571,6 +2573,10 @@ provided a treasure trove of 'non-standard' Sudoku puzzles.
    Add 'null' attribute to generate a puzzle with no topology.
    Add 'quincunx' attribute to generate a quincunx (a.k.a.
      'Samurai Sudoku')
+ 0.009 T. R. Wyant
+   'use 5.006', for 'our' at the very least.
+   Update 'SEE ALSO'
+   add =head1 LICENSE to POD.
 
 =head1 SEE ALSO
 
@@ -2582,6 +2588,14 @@ The Games-Sudoku-Component package by Kenichi Ishigaki (see
 L<http://search.cpan.org/dist/Games-Sudoku-Component/>) both
 generates and solves the standard 9x9 version of the puzzle.
 
+The Games-Sudoku-Component-TkPlayer by Kenichi Ishigaki (see
+L<http://search.cpan.org/dist/Games-Sudoku-Component-TkPlayer/>). Tk
+front end for his Games-Sudoku-Component.
+
+The Games-Sudoku-CPSearch package by Martin-Louis Bright (see
+L<http://search.cpan.prg/dist/Games-Sudoku-CPSearch/>). Solves 9x9
+Sudoku by use of "F" and "N" constraints and backtracking.
+
 The Games-Sudoku-Lite package by Bob O'Neill (see
 L<http://search.cpan.org/dist/Games-Sudoku-Lite/>) solves the standard
 9x9 version of the puzzle.
@@ -2611,8 +2625,11 @@ Thomas R. Wyant, III (F<wyant at cpan dot org>)
 Copyright 2005, 2006, 2008 by Thomas R. Wyant, III
 (F<wyant at cpan dot org>). All rights reserved.
 
-This module is free software; you can use it, redistribute it
-and/or modify it under the same terms as Perl itself.
+=head1 LICENSE
+
+This module is free software; you can use it, redistribute it and/or
+modify it under the same terms as Perl itself. Please see
+L<http://perldoc.perl.org/index-licence.html> for the current licenses.
 
 =cut
 
